//
//  ContentView.swift
//  EnvironmentSetup
//
//  Created by Aliaksandr Andrashuk on 01/07/2023.
//

import SwiftUI
import AVKit

struct ContentView: View {
    let videoEditor = VideoEditor(url: Bundle.main.url(forResource: "IMG_2621", withExtension: "MOV")!)

    @State
    var shareItem: ShareView.Item? = nil

    var body: some View {
        VStack {
            VideoPlayer(player: videoEditor.avPlayer)
                .ignoresSafeArea()

            ZStack {
                Button("Export video", action: exportVideo)
                    .buttonStyle(.borderedProminent)
            }
            .frame(maxHeight: .infinity)
        }
        .sheet(item: $shareItem) { item in
            ShareView(item: item)
        }
    }

    func exportVideo() {
        guard let session = videoEditor.exportSession else {return}

        session.exportAsynchronously {
            guard let url = session.outputURL else {return}
            self.shareItem = ShareView.Item(url: url)
        }
    }
}

struct ShareView: UIViewControllerRepresentable {
    struct Item: Identifiable {
        var id = UUID()
        var url: URL
    }

    let item: Item

    func makeUIViewController(context: Context) -> UIActivityViewController {
        UIActivityViewController(activityItems: [item.url], applicationActivities: nil)
    }

    func updateUIViewController(_ uiViewController: UIActivityViewController, context: Context) {}
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
