//
//  VideoEditor.swift
//  EnvironmentSetup
//
//  Created by Aliaksandr Andrashuk on 01/07/2023.
//

import Foundation
import AVFoundation

class VideoEditor {
    var avPlayerItem: AVPlayerItem? = nil
    var avPlayer: AVPlayer? = nil

    private var asset: AVAsset

    init(url: URL) {
        let url = url
        let asset = AVAsset(url: url)
        let item = AVPlayerItem(asset: asset)

        self.asset = asset
        self.avPlayerItem = item
        self.avPlayer = AVPlayer(playerItem: item)

        buildVideo()
    }

    var exportSession: AVAssetExportSession? {
        let preset = AVAssetExportPreset1920x1080
        guard let session = AVAssetExportSession(asset: asset, presetName: preset)
        else {return nil}

        session.outputURL = FileManager.default.temporaryDirectory.appending(component: UUID().uuidString + ".mov")
        session.outputFileType = .mov
        session.videoComposition = buildComposition()
        
        return session
    }

    func buildVideo() {
        guard let item = avPlayerItem else {return}

        item.videoComposition = buildComposition()
    }

    private func buildComposition() -> AVVideoComposition {
        let composition = AVMutableVideoComposition(propertiesOf: asset)

//        composition.renderScale = 1.0
//        composition.renderSize = CGSize(width: 500.0, height: 400.0)
//        composition.frameDuration = CMTime(value: 1, timescale: 1)

        return composition
    }
}
